==> org.eclipse.php.core.source_3.6.0.201509151953.jar: org/eclipse/php/internal/core/codeassist/contexts/PHPDocContext.java <==
/*******************************************************************************
 * Copyright (c) 2009, 2015 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Zend Technologies
 *******************************************************************************/
package org.eclipse.php.internal.core.codeassist.contexts;

import org.eclipse.dltk.core.CompletionRequestor;
import org.eclipse.dltk.core.ISourceModule;
import org.eclipse.jface.text.BadLocationException;
import org.eclipse.php.internal.core.Constants;
import org.eclipse.php.internal.core.documentModel.partitioner.PHPPartitionTypes;

/**
 * This context represents state when staying in a PHPDoc block. <br/>
 * Example:
 * 
 * <pre>
 *   /**
 *    * |
 * </pre>
 * 
 * @author michael
 */
public abstract class PHPDocContext extends AbstractCompletionContext {

	public boolean isValid(ISourceModule sourceModule, int offset,
			CompletionRequestor requestor) {
		if (!super.isValid(sourceModule, offset, requestor)) {
			return false;
		}
		return isRightPartitionType();
	}

	protected boolean isRightPartitionType() {
		return getPartitionType() == PHPPartitionTypes.PHP_DOC;
	}

	public int getPrefixEnd() throws BadLocationException {
		int prefixEnd = getOffset();
		// NB: getChar(prefixEnd) returns ' ' if offset is at end of document
		while (!Character.isWhitespace(getChar(prefixEnd))
				&& getChar(prefixEnd) != Constants.TYPE_SEPERATOR_CHAR) {
			++prefixEnd;
		}
		return prefixEnd;
	}
}

==> org.eclipse.php.core.source_3.7.0.201602121754.jar: org/eclipse/php/internal/core/codeassist/contexts/PHPDocContext.java <==
/*******************************************************************************
 * Copyright (c) 2009, 2015 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Zend Technologies
 *******************************************************************************/
package org.eclipse.php.internal.core.codeassist.contexts;

import org.eclipse.dltk.core.CompletionRequestor;
import org.eclipse.dltk.core.ISourceModule;
import org.eclipse.jface.text.BadLocationException;
import org.eclipse.php.internal.core.Constants;
import org.eclipse.php.internal.core.documentModel.partitioner.PHPPartitionTypes;

/**
 * This context represents state when staying in a PHPDoc block. <br/>
 * Example:
 * 
 * <pre>
 *   /**
 *    * |
 * </pre>
 * 
 * @author michael
 */
public abstract class PHPDocContext extends AbstractCompletionContext {

	public boolean isValid(ISourceModule sourceModule, int offset, CompletionRequestor requestor) {
		if (!super.isValid(sourceModule, offset, requestor)) {
			return false;
		}
		return isRightPartitionType();
	}

	protected boolean isRightPartitionType() {
		return getPartitionType() == PHPPartitionTypes.PHP_DOC;
	}

	public int getPrefixEnd() throws BadLocationException {
		int prefixEnd = getOffset();
		// NB: getChar(prefixEnd) returns ' ' if offset is at end of document
		while (!Character.isWhitespace(getChar(prefixEnd)) && getChar(prefixEnd) != Constants.TYPE_SEPERATOR_CHAR) {
			++prefixEnd;
		}
		return prefixEnd;
	}
}
